aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.PMR/EmbeddedParameters
diff options
context:
space:
mode:
authorRoy Ben Shabat <Roy.mail.net@gmail.com>2020-11-13 22:16:38 +0200
committerRoy Ben Shabat <Roy.mail.net@gmail.com>2020-11-13 22:16:38 +0200
commit5bb0034f312316bfda66a6ee8d2675b6672f5411 (patch)
treef815b99088bd5a7b675f83413020d2ea41238e86 /Software/Visual_Studio/Tango.PMR/EmbeddedParameters
parent9171be1942bf2368dd9e408e6a51a3c667056ec9 (diff)
downloadTango-5bb0034f312316bfda66a6ee8d2675b6672f5411.tar.gz
Tango-5bb0034f312316bfda66a6ee8d2675b6672f5411.zip
Fixed discrepancies after FSE configuration merge.
Diffstat (limited to 'Software/Visual_Studio/Tango.PMR/EmbeddedParameters')
-rw-r--r--Software/Visual_Studio/Tango.PMR/EmbeddedParameters/AlarmHandlingItem.cs138
1 files changed, 96 insertions, 42 deletions
diff --git a/Software/Visual_Studio/Tango.PMR/EmbeddedParameters/AlarmHandlingItem.cs b/Software/Visual_Studio/Tango.PMR/EmbeddedParameters/AlarmHandlingItem.cs
index 42ff24301..0d957f6be 100644
--- a/Software/Visual_Studio/Tango.PMR/EmbeddedParameters/AlarmHandlingItem.cs
+++ b/Software/Visual_Studio/Tango.PMR/EmbeddedParameters/AlarmHandlingItem.cs
@@ -24,20 +24,21 @@ namespace Tango.PMR.EmbeddedParameters {
string.Concat(
"ChdBbGFybUhhbmRsaW5nSXRlbS5wcm90bxIcVGFuZ28uUE1SLkVtYmVkZGVk",
"UGFyYW1ldGVycxoVQWxhcm1Tb3VyY2VUeXBlLnByb3RvGhZEZWJ1Z0xvZ0Nh",
- "dGVnb3J5LnByb3RvGg9FdmVudFR5cGUucHJvdG8i2wIKEUFsYXJtSGFuZGxp",
+ "dGVnb3J5LnByb3RvGg9FdmVudFR5cGUucHJvdG8igwMKEUFsYXJtSGFuZGxp",
"bmdJdGVtEkIKC0FsYXJtU291cmNlGAEgASgOMi0uVGFuZ28uUE1SLkVtYmVk",
- "ZGVkUGFyYW1ldGVycy5BbGFybVNvdXJjZVR5cGUSEAoIRGV2aWNlSWQYAiAB",
- "KA0SFgoOTW9kdWxlRGV2aWNlSWQYAyABKA0SEgoKQWxhcm1WYWx1ZRgEIAEo",
- "DRIWCg5BbGFybURpcmVjdGlvbhgFIAEoCBI3CghTZXZlcml0eRgGIAEoDjIl",
- "LlRhbmdvLlBNUi5EZWJ1Z2dpbmcuRGVidWdMb2dDYXRlZ29yeRIVCg1EZWJv",
- "dW5jZVZhbHVlGAcgASgNEjMKCUV2ZW50VHlwZRgIIAEoDjIgLlRhbmdvLlBN",
- "Ui5EaWFnbm9zdGljcy5FdmVudFR5cGUSEQoJRXZlbnROYW1lGAkgASgJEhQK",
- "DElzUGVyc2lzdGVudBgKIAEoCEIoCiZjb20udHdpbmUudGFuZ28ucG1yLmVt",
- "YmVkZGVkcGFyYW1ldGVyc2IGcHJvdG8z"));
+ "ZGVkUGFyYW1ldGVycy5BbGFybVNvdXJjZVR5cGUSEQoJRnJlcXVlbmN5GAIg",
+ "ASgNEhAKCERldmljZUlkGAMgASgNEhYKDk1vZHVsZURldmljZUlkGAQgASgN",
+ "EhIKCkFsYXJtVmFsdWUYBSABKA0SFgoOQWxhcm1EaXJlY3Rpb24YBiABKAgS",
+ "NwoIU2V2ZXJpdHkYByABKA4yJS5UYW5nby5QTVIuRGVidWdnaW5nLkRlYnVn",
+ "TG9nQ2F0ZWdvcnkSEwoLUHJlZGVjZXNzb3IYCCABKA0SFQoNRGVib3VuY2VW",
+ "YWx1ZRgJIAEoDRIzCglFdmVudFR5cGUYCiABKA4yIC5UYW5nby5QTVIuRGlh",
+ "Z25vc3RpY3MuRXZlbnRUeXBlEhEKCUV2ZW50TmFtZRgLIAEoCRIUCgxJc1Bl",
+ "cnNpc3RlbnQYDCABKAhCKAomY29tLnR3aW5lLnRhbmdvLnBtci5lbWJlZGRl",
+ "ZHBhcmFtZXRlcnNiBnByb3RvMw=="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { global::Tango.PMR.EmbeddedParameters.AlarmSourceTypeReflection.Descriptor, global::Tango.PMR.Debugging.DebugLogCategoryReflection.Descriptor, global::Tango.PMR.Diagnostics.EventTypeReflection.Descriptor, },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.EmbeddedParameters.AlarmHandlingItem), global::Tango.PMR.EmbeddedParameters.AlarmHandlingItem.Parser, new[]{ "AlarmSource", "DeviceId", "ModuleDeviceId", "AlarmValue", "AlarmDirection", "Severity", "DebounceValue", "EventType", "EventName", "IsPersistent" }, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.EmbeddedParameters.AlarmHandlingItem), global::Tango.PMR.EmbeddedParameters.AlarmHandlingItem.Parser, new[]{ "AlarmSource", "Frequency", "DeviceId", "ModuleDeviceId", "AlarmValue", "AlarmDirection", "Severity", "Predecessor", "DebounceValue", "EventType", "EventName", "IsPersistent" }, null, null, null)
}));
}
#endregion
@@ -69,11 +70,13 @@ namespace Tango.PMR.EmbeddedParameters {
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public AlarmHandlingItem(AlarmHandlingItem other) : this() {
alarmSource_ = other.alarmSource_;
+ frequency_ = other.frequency_;
deviceId_ = other.deviceId_;
moduleDeviceId_ = other.moduleDeviceId_;
alarmValue_ = other.alarmValue_;
alarmDirection_ = other.alarmDirection_;
severity_ = other.severity_;
+ predecessor_ = other.predecessor_;
debounceValue_ = other.debounceValue_;
eventType_ = other.eventType_;
eventName_ = other.eventName_;
@@ -96,13 +99,24 @@ namespace Tango.PMR.EmbeddedParameters {
}
}
- /// <summary>Field number for the "DeviceId" field.</summary>
- public const int DeviceIdFieldNumber = 2;
- private uint deviceId_;
+ /// <summary>Field number for the "Frequency" field.</summary>
+ public const int FrequencyFieldNumber = 2;
+ private uint frequency_;
/// <summary>
- ///uint32 Frequency = 2; //1/10/100/1000
+ ///1/10/100/1000
/// </summary>
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public uint Frequency {
+ get { return frequency_; }
+ set {
+ frequency_ = value;
+ }
+ }
+
+ /// <summary>Field number for the "DeviceId" field.</summary>
+ public const int DeviceIdFieldNumber = 3;
+ private uint deviceId_;
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public uint DeviceId {
get { return deviceId_; }
set {
@@ -111,7 +125,7 @@ namespace Tango.PMR.EmbeddedParameters {
}
/// <summary>Field number for the "ModuleDeviceId" field.</summary>
- public const int ModuleDeviceIdFieldNumber = 3;
+ public const int ModuleDeviceIdFieldNumber = 4;
private uint moduleDeviceId_;
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public uint ModuleDeviceId {
@@ -122,7 +136,7 @@ namespace Tango.PMR.EmbeddedParameters {
}
/// <summary>Field number for the "AlarmValue" field.</summary>
- public const int AlarmValueFieldNumber = 4;
+ public const int AlarmValueFieldNumber = 5;
private uint alarmValue_;
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public uint AlarmValue {
@@ -133,7 +147,7 @@ namespace Tango.PMR.EmbeddedParameters {
}
/// <summary>Field number for the "AlarmDirection" field.</summary>
- public const int AlarmDirectionFieldNumber = 5;
+ public const int AlarmDirectionFieldNumber = 6;
private bool alarmDirection_;
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public bool AlarmDirection {
@@ -144,7 +158,7 @@ namespace Tango.PMR.EmbeddedParameters {
}
/// <summary>Field number for the "Severity" field.</summary>
- public const int SeverityFieldNumber = 6;
+ public const int SeverityFieldNumber = 7;
private global::Tango.PMR.Debugging.DebugLogCategory severity_ = 0;
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public global::Tango.PMR.Debugging.DebugLogCategory Severity {
@@ -154,12 +168,20 @@ namespace Tango.PMR.EmbeddedParameters {
}
}
+ /// <summary>Field number for the "Predecessor" field.</summary>
+ public const int PredecessorFieldNumber = 8;
+ private uint predecessor_;
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public uint Predecessor {
+ get { return predecessor_; }
+ set {
+ predecessor_ = value;
+ }
+ }
+
/// <summary>Field number for the "DebounceValue" field.</summary>
- public const int DebounceValueFieldNumber = 7;
+ public const int DebounceValueFieldNumber = 9;
private uint debounceValue_;
- /// <summary>
- ///uint32 Predecessor = 7;
- /// </summary>
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public uint DebounceValue {
get { return debounceValue_; }
@@ -169,7 +191,7 @@ namespace Tango.PMR.EmbeddedParameters {
}
/// <summary>Field number for the "EventType" field.</summary>
- public const int EventTypeFieldNumber = 8;
+ public const int EventTypeFieldNumber = 10;
private global::Tango.PMR.Diagnostics.EventType eventType_ = 0;
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public global::Tango.PMR.Diagnostics.EventType EventType {
@@ -180,7 +202,7 @@ namespace Tango.PMR.EmbeddedParameters {
}
/// <summary>Field number for the "EventName" field.</summary>
- public const int EventNameFieldNumber = 9;
+ public const int EventNameFieldNumber = 11;
private string eventName_ = "";
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public string EventName {
@@ -191,7 +213,7 @@ namespace Tango.PMR.EmbeddedParameters {
}
/// <summary>Field number for the "IsPersistent" field.</summary>
- public const int IsPersistentFieldNumber = 10;
+ public const int IsPersistentFieldNumber = 12;
private bool isPersistent_;
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public bool IsPersistent {
@@ -215,11 +237,13 @@ namespace Tango.PMR.EmbeddedParameters {
return true;
}
if (AlarmSource != other.AlarmSource) return false;
+ if (Frequency != other.Frequency) return false;
if (DeviceId != other.DeviceId) return false;
if (ModuleDeviceId != other.ModuleDeviceId) return false;
if (AlarmValue != other.AlarmValue) return false;
if (AlarmDirection != other.AlarmDirection) return false;
if (Severity != other.Severity) return false;
+ if (Predecessor != other.Predecessor) return false;
if (DebounceValue != other.DebounceValue) return false;
if (EventType != other.EventType) return false;
if (EventName != other.EventName) return false;
@@ -231,11 +255,13 @@ namespace Tango.PMR.EmbeddedParameters {
public override int GetHashCode() {
int hash = 1;
if (AlarmSource != 0) hash ^= AlarmSource.GetHashCode();
+ if (Frequency != 0) hash ^= Frequency.GetHashCode();
if (DeviceId != 0) hash ^= DeviceId.GetHashCode();
if (ModuleDeviceId != 0) hash ^= ModuleDeviceId.GetHashCode();
if (AlarmValue != 0) hash ^= AlarmValue.GetHashCode();
if (AlarmDirection != false) hash ^= AlarmDirection.GetHashCode();
if (Severity != 0) hash ^= Severity.GetHashCode();
+ if (Predecessor != 0) hash ^= Predecessor.GetHashCode();
if (DebounceValue != 0) hash ^= DebounceValue.GetHashCode();
if (EventType != 0) hash ^= EventType.GetHashCode();
if (EventName.Length != 0) hash ^= EventName.GetHashCode();
@@ -254,40 +280,48 @@ namespace Tango.PMR.EmbeddedParameters {
output.WriteRawTag(8);
output.WriteEnum((int) AlarmSource);
}
- if (DeviceId != 0) {
+ if (Frequency != 0) {
output.WriteRawTag(16);
+ output.WriteUInt32(Frequency);
+ }
+ if (DeviceId != 0) {
+ output.WriteRawTag(24);
output.WriteUInt32(DeviceId);
}
if (ModuleDeviceId != 0) {
- output.WriteRawTag(24);
+ output.WriteRawTag(32);
output.WriteUInt32(ModuleDeviceId);
}
if (AlarmValue != 0) {
- output.WriteRawTag(32);
+ output.WriteRawTag(40);
output.WriteUInt32(AlarmValue);
}
if (AlarmDirection != false) {
- output.WriteRawTag(40);
+ output.WriteRawTag(48);
output.WriteBool(AlarmDirection);
}
if (Severity != 0) {
- output.WriteRawTag(48);
+ output.WriteRawTag(56);
output.WriteEnum((int) Severity);
}
+ if (Predecessor != 0) {
+ output.WriteRawTag(64);
+ output.WriteUInt32(Predecessor);
+ }
if (DebounceValue != 0) {
- output.WriteRawTag(56);
+ output.WriteRawTag(72);
output.WriteUInt32(DebounceValue);
}
if (EventType != 0) {
- output.WriteRawTag(64);
+ output.WriteRawTag(80);
output.WriteEnum((int) EventType);
}
if (EventName.Length != 0) {
- output.WriteRawTag(74);
+ output.WriteRawTag(90);
output.WriteString(EventName);
}
if (IsPersistent != false) {
- output.WriteRawTag(80);
+ output.WriteRawTag(96);
output.WriteBool(IsPersistent);
}
}
@@ -298,6 +332,9 @@ namespace Tango.PMR.EmbeddedParameters {
if (AlarmSource != 0) {
size += 1 + pb::CodedOutputStream.ComputeEnumSize((int) AlarmSource);
}
+ if (Frequency != 0) {
+ size += 1 + pb::CodedOutputStream.ComputeUInt32Size(Frequency);
+ }
if (DeviceId != 0) {
size += 1 + pb::CodedOutputStream.ComputeUInt32Size(DeviceId);
}
@@ -313,6 +350,9 @@ namespace Tango.PMR.EmbeddedParameters {
if (Severity != 0) {
size += 1 + pb::CodedOutputStream.ComputeEnumSize((int) Severity);
}
+ if (Predecessor != 0) {
+ size += 1 + pb::CodedOutputStream.ComputeUInt32Size(Predecessor);
+ }
if (DebounceValue != 0) {
size += 1 + pb::CodedOutputStream.ComputeUInt32Size(DebounceValue);
}
@@ -336,6 +376,9 @@ namespace Tango.PMR.EmbeddedParameters {
if (other.AlarmSource != 0) {
AlarmSource = other.AlarmSource;
}
+ if (other.Frequency != 0) {
+ Frequency = other.Frequency;
+ }
if (other.DeviceId != 0) {
DeviceId = other.DeviceId;
}
@@ -351,6 +394,9 @@ namespace Tango.PMR.EmbeddedParameters {
if (other.Severity != 0) {
Severity = other.Severity;
}
+ if (other.Predecessor != 0) {
+ Predecessor = other.Predecessor;
+ }
if (other.DebounceValue != 0) {
DebounceValue = other.DebounceValue;
}
@@ -378,38 +424,46 @@ namespace Tango.PMR.EmbeddedParameters {
break;
}
case 16: {
- DeviceId = input.ReadUInt32();
+ Frequency = input.ReadUInt32();
break;
}
case 24: {
- ModuleDeviceId = input.ReadUInt32();
+ DeviceId = input.ReadUInt32();
break;
}
case 32: {
- AlarmValue = input.ReadUInt32();
+ ModuleDeviceId = input.ReadUInt32();
break;
}
case 40: {
- AlarmDirection = input.ReadBool();
+ AlarmValue = input.ReadUInt32();
break;
}
case 48: {
- severity_ = (global::Tango.PMR.Debugging.DebugLogCategory) input.ReadEnum();
+ AlarmDirection = input.ReadBool();
break;
}
case 56: {
- DebounceValue = input.ReadUInt32();
+ severity_ = (global::Tango.PMR.Debugging.DebugLogCategory) input.ReadEnum();
break;
}
case 64: {
+ Predecessor = input.ReadUInt32();
+ break;
+ }
+ case 72: {
+ DebounceValue = input.ReadUInt32();
+ break;
+ }
+ case 80: {
eventType_ = (global::Tango.PMR.Diagnostics.EventType) input.ReadEnum();
break;
}
- case 74: {
+ case 90: {
EventName = input.ReadString();
break;
}
- case 80: {
+ case 96: {
IsPersistent = input.ReadBool();
break;
}